## Cloning Functionality

### What is Cloning and Why is it Necessary?
Cloning in the `als-layout` library refers to creating a complete, independent copy of the existing `Layout` instance. This functionality is crucial when you need to generate multiple pages or versions of a page from a single base layout without affecting the original setup.

### How to Use Cloning
To clone a `Layout` instance, simply use the `clone` method. This method creates a new `Layout` instance with the same properties and settings as the original, allowing for independent modifications without interference.

```js
const newLayout = layout.clone;
```

### Benefits of Cloning
- **Efficiency:** Cloning is highly efficient, especially for creating pages with similar structures but different content or styles. It avoids the overhead of reinitializing and reconfiguring a new `Layout` instance from scratch.
- **Speed:** Cloning is fast, typically taking less than 20ms even for large pages. This makes it ideal for high-performance web applications that need to dynamically generate content.
- **Isolation:** Changes made to a cloned `Layout` do not affect the original, ensuring that each instance can be modified independently based on specific requirements.

Cloning is particularly useful in scenarios where templates or base layouts are used repeatedly with slight variations, providing a robust and scalable solution for web page generation.


### propsToClone

You can add properties to add when cloning the object, by adding name of properties to `Layout.propsToClone` which is array.

Example:

```js
Layout.propsToClone.push('projectName')

const layout = new Layout()
layout.projectName = 'Cool project'

const cloned = layout.clone
console.log(cloned.projectName) // 'Cool project'
```