## API

### Constructor

#### `new Layout(html: string, options: object)`

Creates a new `Layout` instance.

- **html**: The initial HTML document string.
- **options**: Configuration options for the layout instance.
  - **minified**: Boolean (default: `false`). Determines if inline CSS and JavaScript should be minified.
  - **logger**: Function (default: `console`). Function for errors in minifiying and url method.
  - **host**:  String (defult:`undefined`). String for url method. 


### Properties

#### `layout.rawHtml`

Returns the inner HTML of the document.

#### `layout.clone`

Creates a clone of the current layout instance, preserving `options`.


#### `__status`

Stores the statusCode for `end` method.

### Methods

#### `lang(lang: string): this`

Sets the `lang` attribute on the `<html>` element.

#### `title(title: string): this`

Sets the document title and creates an Open Graph title meta tag.

#### `description(description: string): this`

Adds description meta tags for SEO and social platforms.

#### `favicon(href: string): this`

Sets or updates the favicon URL.

#### `meta(props: object): this`

Adds or updates a `<meta>` tag with specified attributes.

- **props**: An object where each key-value pair corresponds to a meta attribute.

#### `keywords(keywords: array): this`

Sets or appends keywords in the `content` attribute of a `<meta name="keywords">` tag.

#### `viewport(viewport: string): this`

Sets the viewport meta tag. Default: `width=device-width, initial-scale=1.0`.

#### `image(image: string): this`

Sets meta tags for Open Graph and Twitter cards for an image.

#### `style(styles: string, minified: boolean = this.options.minified): this`

Adds inline CSS to the document. If `minified` is true, the CSS is minified.

- **styles**: CSS string.
- **minified**: Boolean (optional).

#### `url(url: string, host: string = this.URL): this`

Sets the canonical URL and Open Graph URL meta tags.

#### `script(attrs: object = {}, innerHTML: string = '', head: boolean = true, minified: boolean = this.options.minified): this`

Adds a `<script>` tag to the document.

- **attrs**: Attributes for the `<script>` tag.
- **innerHTML**: Inline JavaScript (optional).
- **head**: Boolean (default: `true`). If `false`, the script is added to `<body>`.
- **minified**: Boolean. If true, inline JavaScript is minified.

#### `link(href: string, attributes: object = { rel: "stylesheet", type: "text/css" }): this`

Adds a `<link>` tag for external stylesheets.

#### `status(statusCode:number): this`

Adds the statusCode to `__status` property

#### `end(res):undefined`

Response with res(rawHtml)
