const { Document } = require('als-document');
const { meta, getDescription, getFavicon, getViewport, getImage, script, style, addKeywords, addLink, addUrl } = require('./elements/index')

class Layout extends Document {
   static propsToClone = []; 
   static options = { logger: console, host: '', minified: false }

   constructor(html, options = {}) {
      options = { ...Layout.options, ...options }
      super(html, options.host);
      this.options = options
      this.logger = options.logger || console
      this.root = this.html
   }

   get rawHtml() { return this.innerHTML }
   get clone() { 
      const clone = new this.constructor(new Document(this, this.URL), this.options)
      Layout.propsToClone.forEach(prop => clone[prop] = this[prop])
      return clone
   }

   __status = 200;
   status(status) { this.__status = status; return this }
   end(res) {
      res.writeHead(this.__status, { 'Content-Type': 'text/html' })
      res.end(this.rawHtml)
   }

   lang(lang) { this.html.setAttribute('lang', lang); return this }
   link(href, attributes) { return addLink(href, attributes, this) }
   keywords(keywords = []) { return addKeywords(keywords, this) }
   style(styles, minified = this.options.minified) { return style(styles, minified, this) }
   url(url, host = this.URL) { return addUrl(url, host, this) }
   meta(props) { return meta(props, this) }
   description(description) { return getDescription(description,this) }
   favicon(href) { return getFavicon(href,this) }
   viewport(viewport) { return getViewport(viewport,this) }
   image(image) { return getImage(image,this) }
   script(attrs = {}, innerHTML = '', head = true, minified = this.options.minified) {
      return script(attrs, innerHTML, head, minified, this)
   }

   title(title) {
      super.title // create title tag if not exists
      super.title = title
      this.meta({ property: 'og:title', content: title })
      return this
   }
}

module.exports = Layout