const assert = require('assert');
const { describe, it } = require('node:test')
const Layout = require('../index');

describe('Layout Initialization', () => {
    it('should create an instance of Layout', () => {
        const layout = new Layout();
        assert(layout instanceof Layout, 'layout is not an instance of Layout');
    });

    it('should initialize default language as "en"', () => {
        const layout = new Layout();
        assert(layout.html.getAttribute('lang') === 'en', 'default language is not "en"');
    });

    it('should allow setting a custom language', () => {
        const customLang = 'fr';
        const layout = new Layout(undefined).lang(customLang);
        layout.lang(customLang)
        assert(layout.html.getAttribute('lang') === customLang, `language is not set to ${customLang}`);
    });

    it('should allow setting a custom host', () => {
        const customHost = 'http://localhost';
        const layout = new Layout(undefined,{host:customHost});
        assert.strictEqual(layout.URL, customHost, `host is not set to ${customHost}`);
    });
});
