const assert = require('assert');
const { describe, it, beforeEach } = require('node:test')
const { SingleNode } = require('als-document')
const Layout = require('../index');

describe('Favicon tests', () => {
   let layout;

   beforeEach(() => {
      layout = new Layout();
      // layout.head.insert(1, new SingleNode('title', {})); // Добавляем элемент title для проверки позиции
   });

   it('should update favicon href if link[rel="icon"] already exists', () => {
      const oldHref = 'old-favicon.ico';
      layout.head.insert(2, new SingleNode('link', { rel: 'icon', href: oldHref, type: 'image/x-icon' }));
      const newHref = 'new-favicon.ico';
      layout.favicon(newHref);
      assert.strictEqual(layout.root.$('link[rel="icon"]').getAttribute('href'), newHref, 'Favicon href should be updated');
   });

   it('should insert favicon at the end of head if not present', () => {
      const faviconHref = 'favicon.ico';
      layout.favicon(faviconHref);
      const element = layout.head.childNodes[layout.head.childNodes.length - 1]
      assert.strictEqual(element.tagName, 'LINK', 'Favicon link should be at second position');
      assert.strictEqual(element.getAttribute('href'), faviconHref, 'Favicon href not set correctly');
   });

   it('should add favicon correctly', () => {
      const faviconHref = 'favicon.ico';
      layout.favicon(faviconHref);
      assert.strictEqual(layout.root.$('link[rel="icon"]').getAttribute('href'), faviconHref, 'Favicon not set correctly');
   });

});
