const assert = require('assert');
const { describe, it, beforeEach } = require('node:test')
const Layout = require('../index');

describe('Layout Integrative tests', () => {
   let layout;

   beforeEach(() => layout = new Layout());

   it('should integrate multiple elements correctly', () => {
      layout.title('Test Title');
      layout.description('Test Description');
      layout.keywords(['keyword1', 'keyword2']);

      assert(layout.root.$('title').innerHTML === 'Test Title', 'Title not integrated correctly');
      assert(layout.root.$('meta[name="description"]').getAttribute('content') === 'Test Description', 'Description not integrated correctly');
      assert(layout.root.$('meta[name="keywords"]').getAttribute('content') === 'keyword1,keyword2', 'Keywords not integrated correctly');
   });

   it('should update elements correctly when added multiple times', () => {
      layout.title('First Title');
      assert(layout.root.$('title').innerHTML === 'First Title', 'Title did not update correctly when added multiple times');
      layout.title('Second Title');
      assert(layout.root.$('title').innerHTML === 'Second Title', 'Title did not update correctly when added multiple times');
   });

   it('should remove elements correctly', () => {
      layout.title('Test Title');
      layout.root.$('title').remove();
      assert(layout.root.$('title') === null, 'Title element was not removed correctly');
   });

});

describe('HTML Structure Initialization', () => {
   let layout;

   beforeEach(() => {
      layout = new Layout();
   });

   it('should initialize html element correctly', () => {
      assert.strictEqual(layout.html.tagName, 'HTML', 'HTML element should be initialized');
   });

   it('should not recreate html element if it already exists', () => {
      const existingHtml = layout.html; // вызовем один раз
      assert.strictEqual(layout.html, existingHtml, 'HTML element should not be recreated');
   });

   it('should initialize body element correctly', () => {
      assert.strictEqual(layout.body.tagName, 'BODY', 'Body element should be initialized');
   });

   it('should not recreate body element if it already exists', () => {
      const existingBody = layout.body; // вызовем один раз
      assert.strictEqual(layout.body, existingBody, 'Body element should not be recreated');
   });

   it('should initialize head element correctly', () => {
      assert.strictEqual(layout.head.tagName, 'HEAD', 'Head element should be initialized');
   });

   it('should not recreate head element if it already exists', () => {
      const existingHead = layout.head; // вызовем один раз
      assert.strictEqual(layout.head, existingHead, 'Head element should not be recreated');
   });
});

describe('Clone Testing', () => {
   let layout;
   beforeEach(() => {
      layout = new Layout();
   });

   it('should clone the layout correctly', () => {
      const clone = layout.clone;
      // console.log(clone.constructor.name)
      assert(clone instanceof Layout, 'Clone should be an instance of Layout');
      assert.notStrictEqual(clone, layout, 'Clone should not be the same instance as the original');
   });
});

