const assert = require('assert');
const { describe, it, beforeEach } = require('node:test')
const Layout = require('../index');


describe('Link', () => {
   let layout;
   beforeEach(() => layout = new Layout());

   it('should add a new link element without version', () => {
      const href = 'style.css';
      layout.link(href);
      assert.strictEqual(layout.root.$('link[rel="stylesheet"]').getAttribute('href'), href, 'Link href should match the provided href');
   });

   it('should handle invalid href or version correctly', () => {
      layout.link('', '1.0');
      layout.link(null, '1.0');
      // layout.link('style.css', '');
      // layout.link('style.css', null);
      assert.strictEqual(layout.root.$('link[rel="stylesheet"]'), null, 'Should not add a link when href or version are invalid');
   });

   it('should add link correctly', () => {
      const href = 'style.css';
      layout.link(href);
      assert.strictEqual(layout.root.$('link[rel="stylesheet"]').getAttribute('href'), href, 'Link not set correctly');
   });

   it('should not add a new link element if one already exists with the same href and no version', () => {
      const href = 'style.css';
      layout.link(href);  // Добавление ссылки без версии
      layout.link(href);  // Повторное добавление той же ссылки без версии
      assert.strictEqual(layout.root.$$(`link[rel="stylesheet"][href="${href}"]`).length, 1, 'Should not add duplicate link without version');
   });

   it('should not add a link if href is undefined or null', () => {
      layout.link(undefined, '1.0');
      layout.link(null);
      assert.strictEqual(layout.root.$('link[rel="stylesheet"]'), null, 'Should not add a link when href is undefined or null');
   });

})
