const assert = require('assert');
const { describe, it, beforeEach } = require('node:test')
const Layout = require('../index');

describe('Scripts', () => {
   let layout;

   beforeEach(() => layout = new Layout());

   it('should not add script if attributes are not an object', () => {
      layout.script("not-an-object");
      assert.strictEqual(layout.root.$('script'), null, 'Script should not be added when attributes are not an object');
   });

   it('should not add script if src already exists', () => {
      layout.script({ src: 'existingscript.js' }, 'console.log("test");');
      layout.script({ src: 'existingscript.js' }, 'console.log("duplicate");');
      assert.strictEqual(layout.root.$$(`script[src="existingscript.js"]`).length, 1, 'Duplicate script should not be added');
   });

   it('should handle empty innerHTML correctly', () => {
      layout.script({ src: 'test.js' }, '');
      assert.strictEqual(layout.root.$('script').innerHTML, '', 'Script innerHTML should be empty');
   });

   it('should add script correctly', () => {
      const scriptContent = 'console.log("Hello, world!");';
      layout.script({}, scriptContent);
      assert.strictEqual(layout.root.$('script').innerHTML, scriptContent, 'Script content not set correctly');
   });

   it('should not add script if no attributes and no innerHTML', () => {
      layout.script({}, '');
      assert.strictEqual(layout.root.$('script'), null, 'Script should not be added if there are no attributes and no innerHTML');
   });

   it('should add script after body when head is false', () => {
      const scriptContent = 'console.log("Script in body");';
      layout.script({ src: 'scriptbody.js' }, scriptContent, false);
      assert.strictEqual(layout.body.next.innerHTML, scriptContent, 'Script should be added to body');
   });

})
