const assert = require('assert');
const { describe, it, beforeEach } = require('node:test')
const Layout = require('../index');

describe('Url', () => {
   let layout;
   beforeEach(() => layout = new Layout());

   it('should not add canonical URL if URL is invalid', () => {
      layout.url('not-a-url', 'aa');
      assert.strictEqual(layout.root.$('link[rel="canonical"]'), null, 'Canonical URL should not be added for invalid URLs');
   });
   
   it('should add url correctly', () => {
      const url = 'http://localhost';
      layout.url(url);
      assert(layout.root.$('link[rel="canonical"]').getAttribute('href') === url, 'Canonical URL not set correctly');
   });

   it('should add og:url meta correctly', () => {
      const url = 'http://example.com';
      const host = 'http://example.com';
      layout.url(url, host);
      assert.strictEqual(layout.root.$('meta[property="og:url"]').getAttribute('content'), url, 'og:url meta not set correctly');
   });
   
   it('should add canonical link if not already present', () => {
      const url = 'http://example.com';
      const host = 'http://example.com';
      layout.url(url, host);
      assert.strictEqual(layout.root.$('link[rel="canonical"]').getAttribute('href'), url, 'Canonical link should be added if not present');
   });
   
   it('should update existing canonical link', () => {
      const initialUrl = 'http://example.com/initial';
      const newUrl = 'http://example.com/new';
      const host = 'http://example.com';
      layout.url(initialUrl, host);
      layout.url(newUrl, host);
      assert.strictEqual(layout.root.$('link[rel="canonical"]').getAttribute('href'), newUrl, 'Canonical link should be updated with new URL');
   });
   
   it('should handle invalid URL with valid host', () => {
      layout.url('http://', 'http://example.com');
      assert.strictEqual(layout.root.$('meta[property="og:url"]'), null, 'Meta og:url should not be added for invalid URL');
      assert.strictEqual(layout.root.$('link[rel="canonical"]'), null, 'Canonical link should not be added for invalid URL');
   });
   

})
