const assert = require('assert');
const { describe, it, beforeEach } = require('node:test')
const Layout = require('../index');

describe('layout.viewport',() => {
   let layout;

   beforeEach(() => layout = new Layout());

   it('should update existing viewport meta correctly', () => {
      // Добавляем изначальный viewport
      const initialContent = 'width=device-width, initial-scale=1.0';
      layout.viewport(initialContent);
   
      // Обновляем viewport
      const updatedContent = 'width=device-width, initial-scale=2.0';
      layout.viewport(updatedContent);
   
      // Проверяем, что содержимое meta обновлено
      assert.strictEqual(layout.root.$('meta[name="viewport"]').getAttribute('content'), updatedContent, 'Existing viewport meta content should be updated');
   });
   
   it('should not add a second viewport meta if one already exists', () => {
      // Добавляем изначальный viewport
      const initialContent = 'width=device-width, initial-scale=1.0';
      layout.viewport(initialContent);
   
      // Пытаемся добавить ещё один
      const secondContent = 'width=device-width, initial-scale=2.0';
      layout.viewport(secondContent);
   
      // Проверяем, что в документе только один элемент meta viewport
      assert.strictEqual(layout.root.$$(`meta[name="viewport"]`).length, 1, 'Only one viewport meta should exist');
   });
   
   it('should add viewport correctly', () => {
      const viewportContent = 'width=device-width, initial-scale=1.0';
      layout.viewport(viewportContent);
      assert.strictEqual(layout.root.$('meta[name="viewport"]').getAttribute('content'), viewportContent, 'Viewport not set correctly');
   });
})
